import { Asset, Trade } from '../types';
export interface AlpacaClientError {
    error?: string;
    metadata?: any;
    status?: number;
}
export interface GetLatestTradeResult extends AlpacaClientError {
    symbol?: string;
    trade?: Trade;
}
export interface GetTradesResult extends AlpacaClientError {
    symbol?: string;
    trades?: Trade[];
    next_page_token?: string | null;
}
export interface GetClockResult extends AlpacaClientError {
    timestamp?: string;
    is_open?: boolean;
    next_open?: string;
    next_close?: string;
}
export default class AlpacaClient {
    private baseUrl;
    private baseUrlData;
    private apiKeyId;
    private secretKey;
    private shouldLogUrl;
    private _cache;
    private headers;
    constructor(baseUrl: string, baseUrlData: string, apiKeyId: string, secretKey: string, shouldLogUrl: boolean);
    getCache(cacheKey: string): any;
    getAccount(): Promise<any>;
    getAnnouncements(query: any): Promise<any>;
    getCalendar(query: any): Promise<any>;
    getClock(): Promise<GetClockResult>;
    postOrder(params: any): Promise<any>;
    getOrder({ id }: {
        id: string | number;
    }): Promise<any>;
    getOrders(query: any): Promise<any>;
    replaceOrder({ id, params }: {
        id: string | number;
        params: any;
    }): Promise<any>;
    cancelOrder({ id }: {
        id: string | number;
    }): Promise<any>;
    getPortfolioHistory(query: any): Promise<any>;
    getPosition(symbol: string): Promise<any>;
    getPositions(): Promise<any>;
    closePosition(symbol: string, query?: any): Promise<any>;
    closeAllPositions(): Promise<any>;
    getTrades(symbol: string, query: any): Promise<GetTradesResult>;
    getLatestTrade(symbol: string): Promise<GetLatestTradeResult>;
    getBars(symbol: string, query: any): Promise<any>;
    getBarsCrypto(query: any): Promise<any>;
    getBarsMulti(query: any): Promise<any>;
    getSnapshot(symbol: string): Promise<any>;
    getSnapshotMulti(query: any): Promise<any>;
    getAssets(query: any): Promise<Asset[] | AlpacaClientError>;
    getAsset(symbol: string): Promise<any>;
    getWatchlists(): Promise<any>;
    getWatchlist(id: string | number): Promise<any>;
    createWatchlist(params: any): Promise<any>;
    updateWatchlist(id: string | number, params: any): Promise<any>;
    addAssetToWatchlist(id: string | number, params: any): Promise<any>;
    deleteWatchlist({ id }: {
        id: string | number;
    }): Promise<any>;
    removeAssetFromWatchlist(id: string | number, symbol: string): Promise<any>;
}
