import { StrategyConfig, Strategy } from '../types';
import { HandleStrategyError, StrategemizerRunResult } from './testStrategy';
export interface StrategyResult {
    profit: number;
    variation: number | string | undefined;
    assets?: string;
    result?: string;
}
export type LooseNumber = number | undefined;
export interface StrategemizerGroupIdentifierParams {
    reportDate: string;
    reportTime: string;
    strategy: string;
    strategyConfig: string;
    strategyVersion: string;
}
export interface StrategemizerGroupBase {
    reportDate: string;
    reportTime: string;
    strategy: string;
    strategyConfig: string;
    strategyVersion: string;
    variationsRanCount: number;
    variationsWithResultsCount: number;
}
export interface StrategemizerGroupUpdates extends StrategemizerGroupBase {
    largestProfit: LooseNumber;
    largestLoss: LooseNumber;
    losses: StrategyResult[];
    profits: StrategyResult[];
}
export interface StrategemizerGroupRunStartData extends StrategemizerGroupBase {
    params: Partial<StrategemizerOptions>;
    symbolCount: number;
    variationCount: number;
}
export interface StrategemizerGroupRunResult extends StrategemizerGroupBase {
    largestProfit: LooseNumber;
    largestLoss: LooseNumber;
    params: Partial<StrategemizerOptions>;
    timeElapsed: string;
    timeAtCompletion: string;
    losses: StrategyResult[];
    profits: StrategyResult[];
    summaryFilePath?: string;
    variationCount: number;
}
export interface HandleRunResultData {
    result: StrategemizerRunResult | null;
    groupUpdates: StrategemizerGroupUpdates;
}
export interface HandleSymbolIndexParams extends StrategemizerGroupIdentifierParams {
    symbolIndex: number;
}
export type HandleSymbolIndex = (data: HandleSymbolIndexParams) => Promise<void>;
export interface StrategemizerOptions {
    accountBudget?: number;
    accountBudgetMultiplier?: number;
    accountBudgetPercentPerTrade?: number;
    end: string;
    existingLosses?: StrategyResult[];
    existingProfits?: StrategyResult[];
    existingReportDate?: string;
    existingReportTime?: string;
    handleResult?: (result: HandleRunResultData) => Promise<void>;
    handleStart?: (result: StrategemizerGroupRunStartData) => Promise<void>;
    handleStrategyError?: HandleStrategyError;
    handleSymbolIndex?: HandleSymbolIndex;
    isFractional?: boolean;
    isRandomlySorted?: boolean;
    mainOutputDirectory?: string;
    maxLoops?: number;
    maxLossPercent?: number;
    shouldReturnAssetPaths?: boolean;
    shouldDelayForLogs?: boolean;
    skipToVariation?: string;
    start: string;
    strategy: Strategy;
    strategyConfig: StrategyConfig;
    strategyConfigKey: string;
    strategyKey: string;
    strategyVersion?: string;
    symbols: string[];
    timeframe?: string;
}
declare const strategemizer: ({ accountBudget, accountBudgetMultiplier, accountBudgetPercentPerTrade, end, existingLosses, existingProfits, existingReportDate, existingReportTime, handleResult, handleStart, handleStrategyError, handleSymbolIndex, isFractional, isRandomlySorted, mainOutputDirectory, maxLoops, maxLossPercent, shouldDelayForLogs, shouldReturnAssetPaths, skipToVariation, start, strategy, strategyConfig, strategyConfigKey, strategyKey, strategyVersion, symbols, timeframe, }: StrategemizerOptions) => Promise<StrategemizerGroupRunResult>;
export default strategemizer;
